@@ -67,8 +67,8 @@ of options in a pop-up menu or select box in an HTML form.  Yes, this is the
 often-overlooked (and sometimes ill-supported) "optgroup" HTML tag.
 
 This class inherits from, and follows the conventions of,
-C<Rose::HTML::Form::Field>. Inherited methods that are not overridden will not
-be documented a second time here.  See the C<Rose::HTML::Form::Field>
+L<Rose::HTML::Form::Field>. Inherited methods that are not overridden will not
+be documented a second time here.  See the L<Rose::HTML::Form::Field>
 documentation for more information.
 
 =head1 HTML ATTRIBUTES
@@ -133,7 +133,7 @@ Convenience alias for C<add_options()>.
 
 Adds options to the option group.  OPTIONS may be a reference to a hash of
 value/label pairs, a reference to an array of values, or a list of 
-C<Rose::HTML::Form::Field::Option> objects. Passing an odd number of items in
+L<Rose::HTML::Form::Field::Option> objects. Passing an odd number of items in
 the value/label argument list causes a fatal error. Options passed as a hash
 reference are sorted by value according to the default behavior of Perl's
 built-in C<sort()> function.  Options are added to the end of the existing
@@ -166,7 +166,7 @@ option exists.
 
 Get or set the full list of options in the pop-up menu.  OPTIONS may be a
 reference to a hash of value/label pairs, a reference to an array of values,
-or a list of C<Rose::HTML::Form::Field::Option> objects. Passing an odd number
+or a list of L<Rose::HTML::Form::Field::Option> objects. Passing an odd number
 of items in the value/label argument list causes a fatal error. Options passed
 as a hash reference are sorted by value according to the default behavior of
 Perl's built-in C<sort()> function.
@@ -182,11 +182,11 @@ Example:
         labels  => { apple => 'Apple', pear => 'Pear' });
 
 Remember that methods are called in the order that they appear in the
-constructor arguments (see the C<Rose::Object> documentation), so C<options()>
+constructor arguments (see the L<Rose::Object> documentation), so C<options()>
 will be called before C<labels()> in the example above.  This is important; it
 will not work in the opposite order.
 
-Returns a list of the pop-up menu's C<Rose::HTML::Form::Field::Option> objects
+Returns a list of the pop-up menu's L<Rose::HTML::Form::Field::Option> objects
 in list context, or a reference to an array of the same in scalar context.
 These are the actual objects used in the field. Modifying them will modify the
 field itself.
@@ -205,6 +205,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
\ No newline at end of file
